﻿using System.ComponentModel;
using System.Collections.ObjectModel;
using System.Linq;
using System.Windows.Data;
using System.Windows;

namespace GridViewComboBoxColumn
{
	/// <summary>
	/// A football player.
	/// </summary>
	public class Player : DependencyObject, INotifyPropertyChanged
	{
		public event PropertyChangedEventHandler PropertyChanged;

		private string name;
		private int id;
	
		public string Name
		{
			get { return this.name; }
			set
			{
				if (value != this.name)
				{
					this.name = value;
					this.OnPropertyChanged("Name");
				}
			}
		}

		public int ID
		{
			get { return this.id; }
			set
			{
				if (value != this.id)
				{
					this.id = value;
					this.OnPropertyChanged("ID");
				}
			}
		}
	

		public Player()
		{

		}

		public Player(string name, int id)
		{
			this.name = name;
			this.id = id;		
		}

		protected virtual void OnPropertyChanged(PropertyChangedEventArgs args)
		{
			PropertyChangedEventHandler handler = this.PropertyChanged;
			if (handler != null)
			{
				handler(this, args);
			}
		}

		private void OnPropertyChanged(string propertyName)
		{
			this.OnPropertyChanged(new PropertyChangedEventArgs(propertyName));
		}

		public override string ToString()
		{
			return this.Name;
		}

		public static ObservableCollection<Player> GetPlayers()
		{
			return new ObservableCollection<Player>(Club.GetClubs().SelectMany(c => c.Players));
		}

		public static CollectionViewSource GetPlayersSource()
		{
			ObservableCollection<Player> players = new ObservableCollection<Player>();
			CollectionViewSource playersSource = new CollectionViewSource();
			


			players.Add(new Player("Petr Čech", 1));
			players.Add(new Player("John Terry", 2));
			players.Add(new Player("Frank Lampard", 3));
			players.Add(new Player("Nicolas Anelka", 4));

			playersSource.Source = players;

			return playersSource;
			
		}
	}
}
